/*
 * Copyright 2005-2006 The Portal Application Laboratory Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.sf.pal.blog.portlet;

import java.io.IOException;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.PortletException;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;
import javax.portlet.UnavailableException;

import org.seasar.teeda.core.portlet.FacesPortlet;

public class BlogGenericPortlet extends FacesPortlet
{

    /* (non-Javadoc)
     * @see jp.sf.pal.myfaces.portlet.MyFacesGenericPortlet#init()
     */
    public void init() throws PortletException, UnavailableException
    {
        super.init();
    }

    /* (non-Javadoc)
     * @see jp.sf.pal.myfaces.portlet.MyFacesGenericPortlet#processAction(javax.portlet.ActionRequest, javax.portlet.ActionResponse)
     */
    public void processAction(ActionRequest arg0, ActionResponse arg1) throws PortletException, IOException
    {
        super.processAction(arg0, arg1);
    }

    /* (non-Javadoc)
     * @see javax.portlet.GenericPortlet#render(javax.portlet.RenderRequest, javax.portlet.RenderResponse)
     */
    public void render(RenderRequest arg0, RenderResponse arg1) throws PortletException, IOException
    {
        super.render(arg0, arg1);
    }
}
